@@ -1,19 +1,21 @@
-import { randHash } from '../utils'
-const randUser = randHash()
+import { randUser } from '../utils/index.js'
+const user = randUser()
+const recipient = randUser()
 
 describe('Board', function() {
-	const password = 'pass123'
 
 	before(function() {
-		cy.nextcloudCreateUser(randUser, password)
+		cy.createUser(user)
+		cy.createUser(recipient)
 	})
 
 	beforeEach(function() {
-		cy.login(randUser, password)
+		cy.login(user)
+		cy.visit('/apps/deck')
 	})
 
 	it('Can create a board', function() {
-		const board = 'Test'
+		const board = 'TestBoard'
 
 		cy.intercept({
 			method: 'POST',
@@ -21,7 +23,6 @@ describe('Board', function() {
 		}).as('createBoardRequest')
 
 		// Click "Add board"
-		cy.openLeftSidebar()
 		cy.get('#app-navigation-vue .app-navigation__list .app-navigation-entry')
 			.eq(3).find('a').first().click({ force: true })
 
@@ -38,4 +39,18 @@ describe('Board', function() {
 		cy.get('.app-navigation__list .app-navigation-entry__children .app-navigation-entry')
 			.contains(board).should('be.visible')
 	})
+
+	it('Shows and hides the navigation', () => {
+		cy.get('#app-navigation-vue .app-navigation__list .app-navigation-entry')
+			.contains('Upcoming cards')
+			.should('be.visible')
+		cy.openLeftSidebar()
+		cy.get('#app-navigation-vue .app-navigation__list .app-navigation-entry')
+			.contains('Upcoming cards')
+			.should('not.be.visible')
+		cy.openLeftSidebar()
+		cy.get('#app-navigation-vue .app-navigation__list .app-navigation-entry')
+			.contains('Upcoming cards')
+			.should('be.visible')
+	})
 })
