@@ -77,6 +77,7 @@ OC.L10N.register(
     "{user} has mentioned you in a comment on {deck-card}." : "{user} أشار إليك في تعليق على {deck-card}",
     "The board \"%s\" has been shared with you by %s." : "تمت مشاركة اللوح \"%s\" معك من قبل %s.",
     "{user} has shared {deck-board} with you." : "{user} قام بمشاركة {deck-board} معك.",
+    "Deck board" : "لوح Deck",
     "Card comments" : "تعليقات البطاقة ",
     "%s on %s" : "%s على %s",
     "No data was provided to create an attachment." : "لا بيانات تم تقديمها لانشاء مرفق",
@@ -104,7 +105,6 @@ OC.L10N.register(
     "Path is already shared with this card" : "تم مشاركة المسار بالفعل مع هذه البطاقة ",
     "Invalid date, date format must be YYYY-MM-DD" : "تاريخ غير صحيح, يجب أن يكون تنسيق التاريخ YYYY-MM-DD",
     "Personal planning and team project organization" : "التخطيط الشخصي و تنظيم مشروع الفريق",
-    "Card details" : "تفاصيل البطاقة",
     "Add board" : "إضافة لوح",
     "Select the board to link to a project" : "تحديد اللوح لربطه بمشروع",
     "Search by board title" : "بحث بواسطة عنوان اللوح",
@@ -173,7 +173,6 @@ OC.L10N.register(
     "Delete" : "حذف ",
     "Failed to create share with {displayName}" : "فشل في إنشاء المشاركة مع {displayName}",
     "Transfer" : "نقل",
-    "Add a new list" : "اضف قائمة جديدة",
     "Archive all cards" : "أرشفة جميع البطاقات ",
     "Delete list" : "حذف القائمة",
     "Archive all cards in this list" : "أرشفة جميع البطاقات في القائمة ",
@@ -236,6 +235,7 @@ OC.L10N.register(
     "Assign to me" : "ينسب لي",
     "Unassign myself" : "إلغاء تعييني ",
     "Move card" : "حرك البطاقة",
+    "Card details" : "تفاصيل البطاقة",
     "Unarchive card" : "إلغاء أرشفة البطاقة ",
     "Archive card" : "أرشفة البطاقة",
     "Delete card" : "حذف البطاقة",
@@ -284,8 +284,6 @@ OC.L10N.register(
     "Share with a Deck card" : "مشاركة مع بطاقة Deck",
     "Share {file} with a Deck card" : "مشاركة الملف {file} مع بطاقة Deck",
     "Share" : "مشاركة ",
-    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "دك (Deck) هو أداة تنظيم باسلوب كانبان (kanban) تهدف إلى التخطيط الشخصي وتنظيم المشروع للفرق مع نيكست كلاود (Nextcloud).\n- 📥 إضافة مهامك إلى البطاقات وترتيبها\n- 📄 كتابة ملاحظات إضافية  باستخدام مارك داون (markdown)\n- 🔖 تعيين تسميات لتنظيم أفضل\n- 👥 شارك مع فريقك أو أصدقائك أو عائلتك\n- 📎 إرفاق الملفات وتضمينها بالوصف المستخدم فيه مارك داون (markdown)\n- 💬 ناقش مع فريقك باستخدام التعليقات\n- ⚡ تتبع التغييرات في تيار النشاط\n- 🚀 اجعل مشروعك منظماً",
-    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "هل انت متأكد تريد مسح اللوح {title}؟ هذا سوف يمسح جميع بيانات هذا اللوح.",
-    "This week" : "هذا الأسبوع"
+    "Add a new list" : "اضف قائمة جديدة"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
