@@ -74,6 +74,7 @@ OC.L10N.register(
     "The card \"%s\" on \"%s\" has reached its due date." : "הכרטיס „%s” שתחת „%s” הגיע למועד התפוגה שלו.",
     "%s has mentioned you in a comment on \"%s\"." : "אוזכרת על ידי %s בתגובה על „%s”.",
     "The board \"%s\" has been shared with you by %s." : "הלוח „%s” שותף אתך על ידי %s.",
+    "Deck board" : "לוח חסיפה",
     "No data was provided to create an attachment." : "לא סופקו נתונים ליצירת קובץ מצורף",
     "Finished" : "הסתיים",
     "To review" : "לסקירה",
@@ -99,7 +100,6 @@ OC.L10N.register(
     "Path is already shared with this card" : "הנתיב כבר משותף עם הכרטיס הזה",
     "Invalid date, date format must be YYYY-MM-DD" : "תאריך שגוי, תבנית התאריך חייבת להיות YYYY-MM-DD",
     "Personal planning and team project organization" : "ארגון אישי וקבוצתי של מיזמים",
-    "Card details" : "פרטי הכרטיס",
     "Add board" : "הוספת לוח",
     "Select the board to link to a project" : "נא לבחור את הלוח לקישור למיזם",
     "Search by board title" : "חיפוש לפי כותרת לו",
@@ -163,7 +163,6 @@ OC.L10N.register(
     "Delete" : "מחיקה",
     "Failed to create share with {displayName}" : "יצירת השיתוף עם {displayName} נכשלה",
     "Transfer" : "העברה",
-    "Add a new list" : "הוסף רשימה חדשה",
     "Archive all cards" : "ארכיב את כל הכרטיסים",
     "Delete list" : "מחיקת רשימה",
     "Archive all cards in this list" : "ארכיב את כל הכרטיסים ברשימה זו",
@@ -223,6 +222,7 @@ OC.L10N.register(
     "Assign to me" : "הקצאה אלי",
     "Unassign myself" : "לבטל את הקצאת עצמי",
     "Move card" : "העברת כרטיס",
+    "Card details" : "פרטי הכרטיס",
     "Unarchive card" : "הוצאת הכרטיס מהארכיון",
     "Archive card" : "העברת כרטיס לארכיון",
     "Delete card" : "מחיקת כרטיס לארכיון",
@@ -268,8 +268,6 @@ OC.L10N.register(
     "Share with a Deck card" : "שיתוף עם כרטיס חפיסה",
     "Share {file} with a Deck card" : "שיתוף {file} עם כרטיס חפיסה",
     "Share" : "שיתוף",
-    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck הוא כלי ארגון בסגנון kanban המכוון לתכנון אישי ולארגון פרויקטים עבור צוותים המשולבים ב- Nextcloud.\n\n\n- 📥 הוסף את המשימות שלך לכרטיסים וסדר אותן\n- 📄 רשמו הערות נוספות ב-markdown\n- 🔖הקצה תוויות לארגון טוב עוד יותר\n- 👥 שתף עם הצוות שלך, חברים, או משפחה\n- 📎 צרף קבצים והטמע אותם בתיאור ה-markdown שלך\n- 💬 שוחח עם הצוות שלך באמצעות הערות\n- ⚡ עקוב אחר שינויים בזרם הפעילות\n- 🚀 ארגנו את הפרויקט שלכם",
-    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "למחוק את הלוח {title}? פעולה זו תמחק את כל הנתונים של הלוח הזה.",
-    "This week" : "השבוע"
+    "Add a new list" : "הוסף רשימה חדשה"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
