@@ -78,6 +78,7 @@ OC.L10N.register(
     "{user} has mentioned you in a comment on {deck-card}." : "{user} さんが 「{deck-card}」のコメント内であなたについて言及しました。",
     "The board \"%s\" has been shared with you by %s." : "\"%s\" ボードは、%s からあなたに共有されています。",
     "{user} has shared {deck-board} with you." : "{user} さんが、あなたと {deck-board} を共有しました。",
+    "Deck board" : "Deckボード",
     "Card comments" : "カードコメント",
     "%s on %s" : "%s が %s で",
     "No data was provided to create an attachment." : "添付ファイルを作成するためのデータは提供されていません。",
@@ -107,7 +108,6 @@ OC.L10N.register(
     "Invalid date, date format must be YYYY-MM-DD" : "日付が無効です。日付形式はYYYY-MM-DDである必要があります",
     "Personal planning and team project organization" : "個人的な計画とチームのプロジェクト編成",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "DeckはNextcloudと統合された、チームのための個人計画とプロジェクトの組織化を目的としたカンバンスタイルのオーガナイズツールです。\n\n\n- 📥 タスクをカードに追加して整理する\n- 📄 追加のメモをマークダウン形式で書き留める\n- 🔖 より詳細な分類のために追加のラベルを割り当てる\n- 👥 チーム、友達、家族と共有\n- 📎 ファイルを添付し、マークダウンの説明に埋め込む\n- 💬 コメントを使用してチームで話し合う\n- ⚡ アクティビティストリームで変更を追跡する\n- 🚀 プロジェクトを整理する",
-    "Card details" : "カード詳細",
     "Add board" : "ボードを追加",
     "Select the board to link to a project" : "プロジェクトにリンクするボードを選択",
     "Search by board title" : "ボードのタイトルで検索",
@@ -181,7 +181,6 @@ OC.L10N.register(
     "Transfer" : "転送",
     "The board has been transferred to {user}" : "ボードが {user} に転送されました。",
     "Failed to transfer the board to {user}" : "{user} へのボードの転送に失敗しました",
-    "Add a new list" : "新しいリストを追加",
     "Archive all cards" : "すべてのカードをアーカイブする",
     "Delete list" : "リストを削除",
     "Archive all cards in this list" : "このリストのすべてのカードをアーカイブする",
@@ -246,6 +245,7 @@ OC.L10N.register(
     "Assign to me" : "自分に割り当てる",
     "Unassign myself" : "自分への割り当てを解除",
     "Move card" : "カードの移動",
+    "Card details" : "カード詳細",
     "Unarchive card" : "カードのアーカイブを解除する",
     "Archive card" : "カードをアーカイブ",
     "Delete card" : "カードを削除する",
@@ -295,12 +295,6 @@ OC.L10N.register(
     "Share with a Deck card" : "デッキのカードで共有する",
     "Share {file} with a Deck card" : "{file}をデッキのカードで共有する",
     "Share" : "共有",
-    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "DeckはNextcloudと統合した、チームの個人計画とプロジェクトの組織化を目的としたカンバンスタイルの組織ツールです。\n\n\n- 📥 タスクをカードに追加して整理する\n- 📄 マークダウンで追加のメモを書き留めます\n- 🔖 より良い組織のためにラベルを割り当てる\n- 👥 あなたのチーム、友人、家族と共有する\n- 📎 ファイルを添付してマークダウンの説明に埋め込む\n- 💬 コメントを使ってあなたのチームと話し合う\n- ⚡ アクティビティの流れの変化を追跡する\n- 🚀 プロジェクトを整理する",
-    "Are you sure you want to transfer the board {title} for {user} ?" : "本当に、 {user} のボード {title} を転送してもよろしいですか？",
-    "Transfer the board for {user} successfully" : "{user} のボードの転送に成功しました",
-    "Failed to transfer the board for {user}" : "{user} のボードの転送に失敗しました",
-    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "このボード{title}を削除してもよろしいですか？この操作はこのボードのデータすべてを削除します。",
-    "This week" : "今週",
-    "Are you sure you want to transfer the board {title} for {user}?" : "本当に、 {user} のボード {title} を転送してもよろしいですか？"
+    "Add a new list" : "新しいリストを追加"
 },
 "nplurals=1; plural=0;");
