@@ -70,6 +70,7 @@ OC.L10N.register(
     "Personal" : "Asmeniniai",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kortelę \"%s\" ties \"%s\" priskyrė jums %s.",
     "The card \"%s\" on \"%s\" has reached its due date." : "Kortelė „%s“, esanti lentoje „%s“, pasiekė savo galutinį terminą.",
+    "The card {deck-card} on {deck-board} has reached its due date." : "Kortelė {deck-card}, esanti lentoje {deck-board} pasiekė savo galutinio termino datą.",
     "%s has mentioned you in a comment on \"%s\"." : "%s paminėjo jus komentare ties \"%s\".",
     "The board \"%s\" has been shared with you by %s." : "Lentą \"%s\" su jumis bendrina %s.",
     "%s on %s" : "%s ant %s",
@@ -98,7 +99,6 @@ OC.L10N.register(
     "Path is already shared with this card" : "Kelias jau yra bendrinamas su šia kortele",
     "Invalid date, date format must be YYYY-MM-DD" : "Netinkama data, datos formatas privalo būti MMMM-mm-dd",
     "Personal planning and team project organization" : "Asmeninis planavimas ir komandinių projektų organizavimas",
-    "Card details" : "Išsamiau apie kortelę",
     "Add board" : "Pridėti lentą",
     "Select the board to link to a project" : "Pasirinkite lentą, kurią susieti su projektu",
     "Search by board title" : "Ieškoti pagal lentos pavadinimą",
@@ -165,7 +165,6 @@ OC.L10N.register(
     "Delete" : "Ištrinti",
     "Failed to create share with {displayName}" : "Nepavyko sukurti viešinio su {displayName}",
     "Transfer" : "Persiųsti",
-    "Add a new list" : "Pridėti naują sąrašą",
     "Archive all cards" : "Archyvuoti visas korteles",
     "Delete list" : "Ištrinti sąrašą",
     "Archive all cards in this list" : "Archyvuoti visas korteles šiame sąraše",
@@ -200,9 +199,9 @@ OC.L10N.register(
     "Assign to users" : "Priskirti naudotojams",
     "Assign to users/groups/circles" : "Priskirti naudotojams/grupėms/ratams",
     "Assign a user to this card…" : "Priskirti šiai kortelei naudotoją…",
-    "Due date" : "Terminas",
+    "Due date" : "Galutinio termino data",
     "Set a due date" : "Nustatyti galutinį terminą",
-    "Remove due date" : "Pašalinti terminą",
+    "Remove due date" : "Šalinti galutinio termino datą",
     "Select Date" : "Pasirinkti datą",
     "Today" : "Šiandien",
     "Tomorrow" : "Rytoj",
@@ -226,6 +225,7 @@ OC.L10N.register(
     "{count} comments, {unread} unread" : "Komentarų: {count}, neskaityta: {unread}",
     "Assign to me" : "Priskirti sau",
     "Move card" : "Perkelti kortelę",
+    "Card details" : "Išsamiau apie kortelę",
     "Unarchive card" : "Išarchyvuoti kortelę",
     "Archive card" : "Archyvuoti kortelę",
     "Delete card" : "Ištrinti kortelę",
@@ -243,9 +243,9 @@ OC.L10N.register(
     "Clone board" : "Dubliuoti lentą",
     "Unarchive board" : "Išarchyvuoti lentą",
     "Archive board" : "Archyvuoti lentą",
-    "Turn on due date reminders" : "Įjungti priminimus apie galutinį terminą",
-    "Turn off due date reminders" : "Išjungti priminimus apie galutinį terminą",
-    "Due date reminders" : "Priminimai apie galutinį terminą",
+    "Turn on due date reminders" : "Įjungti priminimus apie galutinio termino datą",
+    "Turn off due date reminders" : "Išjungti priminimus apie galutinio termino datą",
+    "Due date reminders" : "Priminimai apie galutinio termino datą",
     "All cards" : "Visos kortelės",
     "Assigned cards" : "Priskirtos kortelės",
     "No notifications" : "Pranešimų nėra",
@@ -257,6 +257,7 @@ OC.L10N.register(
     "Delete the board?" : "Ištrinti lentą?",
     "No due" : "Be galutinio termino",
     "No results found" : "Nerasta jokių rezultatų",
+    "Due on {date}" : "Galutinis terminas {date}",
     "Link to a board" : "Susieti su lenta",
     "Link to a card" : "Susieti su kortele",
     "Create a card" : "Sukurti kortelę",
@@ -264,7 +265,6 @@ OC.L10N.register(
     "Maximum file size of {size} exceeded" : "Viršytas maksimalus {size} failo dydis",
     "Error creating the share" : "Klaida kuriant viešinį",
     "Share" : "Bendrinti",
-    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Ar tikrai norite ištrinti lentą, pavadinimu {title}? Tai ištrins visus šios lentos duomenis.",
-    "This week" : "Šią savaitę"
+    "Add a new list" : "Pridėti naują sąrašą"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
