@@ -47,7 +47,6 @@ OC.L10N.register(
     "Shared with you" : "Koplietots ar tevi",
     "No notifications" : "Nav paziņojumu",
     "An error occurred" : "Gadījās kļūda",
-    "Share" : "Koplietot",
-    "This week" : "Šonedēļ"
+    "Share" : "Koplietot"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
