@@ -78,6 +78,7 @@ OC.L10N.register(
     "{user} has mentioned you in a comment on {deck-card}." : "{user} vas omeni v opombi na »{deck-card}«.",
     "The board \"%s\" has been shared with you by %s." : "Zbirko »%s« vam dodeli %s.",
     "{user} has shared {deck-board} with you." : "{user} vam omogoča souporabo zbirke {deck-board}.",
+    "Deck board" : "Zbirka Deck",
     "Card comments" : "Opombe k nalogi",
     "%s on %s" : "%s v nalogi %s",
     "No data was provided to create an attachment." : "Ni podanih podatkov za ustvarjanje priloge.",
@@ -105,7 +106,6 @@ OC.L10N.register(
     "Path is already shared with this card" : "Pot je že povezana s to nalogo",
     "Invalid date, date format must be YYYY-MM-DD" : "Neveljaven zapis časa; biti mora v zapisu YYYY-MM-DD",
     "Personal planning and team project organization" : "Osebno načrtovanje nalog in organizacija skupinskih projektov",
-    "Card details" : "Podrobnosti naloge",
     "Add board" : "Dodaj zbirko",
     "Select the board to link to a project" : "Izberite zbirko za povezavo s projektom",
     "Search by board title" : "Išči po imenu zbirke",
@@ -174,7 +174,6 @@ OC.L10N.register(
     "Delete" : "Izbriši",
     "Failed to create share with {displayName}" : "Souporaba z uporabnikom {displayName} je spodletela",
     "Transfer" : "Prenos",
-    "Add a new list" : "Dodaj nov seznam",
     "Archive all cards" : "Arhiviraj vse kartice",
     "Delete list" : "Izbriši seznam",
     "Archive all cards in this list" : "Arhiviraj vse kartice tega seznama",
@@ -238,6 +237,7 @@ OC.L10N.register(
     "Assign to me" : "Nalogo dodeli meni",
     "Unassign myself" : "Odstrani me z naloge",
     "Move card" : "Premakni nalogo",
+    "Card details" : "Podrobnosti naloge",
     "Unarchive card" : "Povrni nalogo",
     "Archive card" : "Arhiviraj nalogo",
     "Delete card" : "Izbriši nalogo",
@@ -274,6 +274,7 @@ OC.L10N.register(
     "Search for {searchQuery} in all boards" : "Poišči {searchQuery} med vsemi zbirkami nalog.",
     "No results found" : "Ni najdenih zadetkov",
     "{stack} in {board}" : "{stack} v {board}",
+    "Click to expand comment" : "Kliknite za razširitev opombe",
     "No upcoming cards" : "Ni prihajajočih nalog",
     "upcoming cards" : "prihajajoče naloge",
     "Link to a board" : "Povezava do zbirke",
@@ -287,8 +288,6 @@ OC.L10N.register(
     "Share with a Deck card" : "Poveži z nalogo Deck",
     "Share {file} with a Deck card" : "Poveži datoteko {file} z nalogo Deck",
     "Share" : "Souporaba",
-    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Program Deck je orodje za osebno načrtovanje in projektno delo v slogu kanban, ki se izvrstno vključuje v okolje Nextcloud.\n\nOrodje omogoča:\n- 📥 dodajanje in urejanje nalog\n- 📄 zapis dodatnih opomb v zapisu markdown\n- 🔖 dodeljevanje oznak za lažje urejanje in iskanje\n- 👥 souporabo v skupini, s prijatelji ali družino\n- 📎 pripenjanje in vstavljanje datotek v opise\n- 💬 opombe k posamezni nalogi\n- ⚡ sledenje spremembam in dejavnosti\n- 🚀 Organizaciji projekta",
-    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Ali ste prepričani, da želite izbrisati zbirko »{title}«? S tem boste izbrisali tudi vse podatke zbirke.",
-    "This week" : "Ta teden"
+    "Add a new list" : "Dodaj nov seznam"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
