@@ -78,6 +78,7 @@ OC.L10N.register(
     "{user} has mentioned you in a comment on {deck-card}." : "{user} 在 {deck-card} 的一条评论中提到了你",
     "The board \"%s\" has been shared with you by %s." : "面板 \"%s\" 已由 %s 共享给您。",
     "{user} has shared {deck-board} with you." : "{user} 与你分享了 {deck-board}",
+    "Deck board" : "Deck 看板",
     "Card comments" : "卡片评论",
     "%s on %s" : "%s 于 %s",
     "No data was provided to create an attachment." : "未能提供数据以创建附件",
@@ -105,7 +106,6 @@ OC.L10N.register(
     "Path is already shared with this card" : "已和这张卡片分享了路径",
     "Invalid date, date format must be YYYY-MM-DD" : "无效日期，日期格式必须为 YYYY-MM-DD",
     "Personal planning and team project organization" : "个人规划和团队项目安排",
-    "Card details" : "卡片详情",
     "Add board" : "添加面板",
     "Select the board to link to a project" : "选择要链接到一个项目的面板",
     "Search by board title" : "通过标题搜索面板",
@@ -134,6 +134,7 @@ OC.L10N.register(
     "Archived cards" : "已归档卡片",
     "Add list" : "添加列表",
     "List name" : "列表名称",
+    "Active filters" : "已开启的过滤器",
     "Apply filter" : "应用筛选",
     "Filter by tag" : "按标签筛选",
     "Filter by assigned user" : "按指派的用户筛选",
@@ -172,9 +173,8 @@ OC.L10N.register(
     "Can manage" : "可以管理",
     "Owner" : "所有者",
     "Delete" : "删除",
-    "Failed to create share with {displayName}" : "用 {displayName} 创建分享失败",
+    "Failed to create share with {displayName}" : "用{displayName}创建分享失败",
     "Transfer" : "传输",
-    "Add a new list" : "添加新列表",
     "Archive all cards" : "归档所有卡片",
     "Delete list" : "删除列表",
     "Archive all cards in this list" : "将该列表中的所有卡片归档",
@@ -235,10 +235,13 @@ OC.L10N.register(
     "Write a description …" : "写一段描述",
     "Choose attachment" : "选择附件",
     "(group)" : "（组）",
+    "Todo items" : "待办事项",
     "{count} comments, {unread} unread" : "{count} 条评论，{unread} 未读",
+    "Edit card title" : "编辑卡片标题",
     "Assign to me" : "指派给我",
     "Unassign myself" : "不再指派给我",
     "Move card" : "移动卡片",
+    "Card details" : "卡片详情",
     "Unarchive card" : "撤销对卡片的归档",
     "Archive card" : "归档卡片",
     "Delete card" : "删除卡片",
@@ -275,6 +278,7 @@ OC.L10N.register(
     "Search for {searchQuery} in all boards" : "在所有看板中搜索 {searchQuery}",
     "No results found" : "未找到结果",
     "{stack} in {board}" : "{stack} 于 {board}",
+    "Click to expand description" : "点击展开描述",
     "No upcoming cards" : "没有即将到来的卡片",
     "upcoming cards" : "即将到来的卡片",
     "Link to a board" : "链接到一个面板",
@@ -282,14 +286,12 @@ OC.L10N.register(
     "Create a card" : "创建一张卡片",
     "Message from {author} in {conversationName}" : "{conversationName} 会话中来自 {author} 的消息",
     "Something went wrong" : "发生了错误",
-    "Failed to upload {name}" : "未能上传 {name}",
+    "Failed to upload {name}" : "未能上传{name}",
     "Maximum file size of {size} exceeded" : "文件容量已超过 {size} 的上限",
     "Error creating the share" : "创建分享出错",
     "Share with a Deck card" : "分享给一张看板卡片",
     "Share {file} with a Deck card" : "将{file}分享给一张看板卡片",
     "Share" : "分享",
-    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "“看板”是 Nextcloud 集成的一款看板式任务管理工具，用于个人计划与项目安排。\n\n\n- 📥 将您的任务添加到卡片上，并将它们有序排列\n- 📄 将您的补充说明用markdown写下来\n- 🔖 利用指派标签更好地进行筹划\n- 👥 与您的团队，朋友或家人共享\n- 📎 附加文件并将它们嵌入到您的markdown说明中\n- 💬 用评论与您的团队讨论\n- ⚡ 在活动流中紧跟变化\n- 🚀 使您的项目井井有条",
-    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "你确定你要删除 {title}面板吗？面板内所有数据都将因此被删除。",
-    "This week" : "本周"
+    "Add a new list" : "添加新列表"
 },
 "nplurals=1; plural=0;");
