@@ -78,8 +78,13 @@ OC.L10N.register(
     "{user} has mentioned you in a comment on {deck-card}." : "{user} 在 {deckcard} 的意見中提到了您。",
     "The board \"%s\" has been shared with you by %s." : "面板 \"%s\" 已由 %s 分享給您。",
     "{user} has shared {deck-board} with you." : "{user} 分享了面板 {deck-board} 給您。",
+    "Deck board" : "Deck 面板",
+    "Owned by %1$s" : "由 %1$s 擁有",
+    "Deck boards, cards and comments" : "Deck 面板、卡片和評論",
+    "From %1$s, in %2$s/%3$s, owned by %4$s" : "來自 %1$s，位於 %2$s/%3$s，由 %4$s 擁有",
     "Card comments" : "卡片意見",
     "%s on %s" : "%s上%s",
+    "Deck boards and cards" : "Deck 面板及卡片",
     "No data was provided to create an attachment." : "未能提供數據以創建附件",
     "Finished" : "完成",
     "To review" : "待審閱",
@@ -107,7 +112,6 @@ OC.L10N.register(
     "Invalid date, date format must be YYYY-MM-DD" : "無效的日期，需為 YYYY-MM-DD 格式",
     "Personal planning and team project organization" : "個人規劃和團隊項目組織",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck是一種看板式組織工具，旨在針對與Nextcloud集成的團隊進行個人計劃和項目組織。\n\n\n- 📥 添加您的任務到 card 及將之整理好\n- 📄 用 Markdown 寫下額外的註釋分享分享分享\n- 🔖 分配標籤以更好地組織您的工作\n- 👥 與您的團隊、朋友或家人分享\n- 📎 附加檔案並將其嵌入到您的 Markdown 描述中 \n- 💬 使用意見與您的團隊討論\n- ⚡ 在活動流中跟踪更改\n- 🚀 讓您的專案井井有條",
-    "Card details" : "卡片詳情",
     "Add board" : "添加面板",
     "Select the board to link to a project" : "選擇要連結到一個項目的面板",
     "Search by board title" : "通過標題搜索面板",
@@ -153,6 +157,7 @@ OC.L10N.register(
     "Toggle compact mode" : "切換簡潔模式",
     "Open details" : "開啟細節",
     "Details" : "詳情",
+    "Currently present people" : "目前在場人仕",
     "Loading board" : "正在加載面板",
     "No lists available" : "無清單可用",
     "Create a new list to add cards to this board" : "創建一張新清單來添加卡片到這個看板",
@@ -181,10 +186,12 @@ OC.L10N.register(
     "Transfer" : "轉移",
     "The board has been transferred to {user}" : "面板已轉讓給 {user}",
     "Failed to transfer the board to {user}" : "未能將面板轉移給 {user}",
-    "Add a new list" : "添加一張新清單",
+    "Edit list title" : "編輯清單標題",
     "Archive all cards" : "封存所有卡片",
+    "Unarchive all cards" : "解除封存所有卡片",
     "Delete list" : "刪除清單",
     "Archive all cards in this list" : "封存此清單內的所有卡片",
+    "Unarchive all cards in this list" : "解除封存所有此列表中的卡片",
     "Add a new card" : "添加一張新卡片",
     "Card name" : "卡片名稱",
     "List deleted" : "清單已被刪除",
@@ -248,6 +255,7 @@ OC.L10N.register(
     "Assign to me" : "指派給我",
     "Unassign myself" : "自己解除指派",
     "Move card" : "移動卡片",
+    "Card details" : "卡片詳情",
     "Unarchive card" : "取消對卡片的封存",
     "Archive card" : "封存卡片",
     "Delete card" : "刪除卡片",
@@ -260,6 +268,7 @@ OC.L10N.register(
     "Shared with you" : "收到的分享",
     "Deck settings" : "看板設定",
     "Use bigger card view" : "使用較大的卡片視圖",
+    "Show card ID badge" : "顯示卡片 ID 徽章",
     "Show boards in calendar/tasks" : "在日曆/任務中顯示面板",
     "Limit deck usage of groups" : "限制群組使用 Deck",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "限制 Deck 將阻止不屬於這些群組的用戶創建自己的面板。用戶仍然可以在與他們的面板上工作。",
@@ -268,6 +277,7 @@ OC.L10N.register(
     "Clone board" : "複製面板",
     "Unarchive board" : "取消對面板的封存",
     "Archive board" : "封存面板",
+    "Export board" : "導出面板",
     "Turn on due date reminders" : "開啟到期日提醒",
     "Turn off due date reminders" : "關閉到期日提醒",
     "Due date reminders" : "到期日提醒",
@@ -285,11 +295,15 @@ OC.L10N.register(
     "No due" : "沒有到期的",
     "Search for {searchQuery} in all boards" : "在所有面板中搜索 {searchQuery}",
     "No results found" : "沒有結果",
+    "Deck board {name}\n* Last modified on {lastMod}" : "Deck 面板 {name}\n* 最後修改於  {lastMod}",
     "{stack} in {board}" : "{board} 中的 {stack}",
+    "Click to expand description" : "點擊展開描述",
     "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* 創建於 {created}\n* 最後修改於 {lastMod}\n* {nbAttachments} 個附件\n* {nbComments} 則留言",
     "{nbCards} cards" : "{nbCards} 張卡片",
+    "Click to expand comment" : "點擊展開評論",
     "No upcoming cards" : "沒有快將到期的卡片",
     "upcoming cards" : "快將到期的卡片",
+    "New card" : "新卡片",
     "Due on {date}" : "於 {date} 到期",
     "Link to a board" : "連結到面板",
     "Link to a card" : "連結到卡片",
@@ -302,12 +316,6 @@ OC.L10N.register(
     "Share with a Deck card" : "用一張 Deck 卡片進行分享 ",
     "Share {file} with a Deck card" : "用一張 Deck 卡片分享 {file}",
     "Share" : "分享",
-    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck是一種看板式組織工具，旨在針對與Nextcloud集成的團隊進行個人計劃和項目組織。\n\n\n- 📥 增加您的任務到card和把它們整理好\n- 📄 寫下額外的筆記在markdown\n- 🔖 分配標籤以更好地組織您的工作\n- 👥 與您的團隊，朋友或家人分享\n- 📎 附加檔案並將其嵌入到您的 markdown 描述\n- 💬 使用意見與您的團隊討論\n- ⚡ 在活動流中跟踪更改\n- 🚀 讓您的項目井井有條",
-    "Are you sure you want to transfer the board {title} for {user} ?" : "您想要轉移 {user} 的面板 {title} 嗎？",
-    "Transfer the board for {user} successfully" : "轉移 {user} 的面板成功",
-    "Failed to transfer the board for {user}" : "轉移 {user} 的面板失敗",
-    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "你確定你要刪除 {title} 面板嗎？面板內所有數據都將因此被刪除。",
-    "This week" : "本星期",
-    "Are you sure you want to transfer the board {title} for {user}?" : "您想要轉移 {user} 的面板 {title} 嗎？"
+    "Add a new list" : "添加一張新清單"
 },
 "nplurals=1; plural=0;");
