@@ -78,8 +78,13 @@ OC.L10N.register(
     "{user} has mentioned you in a comment on {deck-card}." : "{user} 在 {deck-card} 的留言中提及您。",
     "The board \"%s\" has been shared with you by %s." : "佈告欄「%s」已由 %s 分享給您。",
     "{user} has shared {deck-board} with you." : "{user} 已與您分享 {deck-board}。",
+    "Deck board" : "Deck 佈告欄",
+    "Owned by %1$s" : "由 %1$s 擁有",
+    "Deck boards, cards and comments" : "Deck 看板、卡片與評論",
+    "From %1$s, in %2$s/%3$s, owned by %4$s" : "來自 %1$s，在 %2$s/%3$s，由 %4$s 擁有",
     "Card comments" : "卡片留言",
     "%s on %s" : "%s 在 %s",
+    "Deck boards and cards" : "Deck 看板與卡片",
     "No data was provided to create an attachment." : "沒有提供用於建立附件的資料。",
     "Finished" : "已完成",
     "To review" : "待檢閱",
@@ -107,7 +112,6 @@ OC.L10N.register(
     "Invalid date, date format must be YYYY-MM-DD" : "無效的日期，日期格式必須為 YYYY-MM-DD",
     "Personal planning and team project organization" : "個人規劃與團隊專案組織",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck 是一套看板式組織工具，提供與 Nextcloud 整合的個人規劃與團隊專案組織功能。\n\n\n- 📥 將您的工作項目新增到卡片中，並將它們按順序排列\n- 📄 以 Markdown 編寫額外的註釋\n- 🔖 分配標籤讓組織更方便\n- 👥 與您的團隊、朋友與家人分享\n- 📎 附上檔案並將其嵌入到您的 Markdown 描述中\n- 💬 使用留言與您的團隊討論\n- ⚡ 追蹤活動流程中的變動\n- 🚀 整理好您的專案",
-    "Card details" : "卡片詳細資訊",
     "Add board" : "新增佈告欄",
     "Select the board to link to a project" : "選取要連結到專案的佈告欄",
     "Search by board title" : "按佈告欄標題搜尋",
@@ -153,6 +157,7 @@ OC.L10N.register(
     "Toggle compact mode" : "切換簡潔模式",
     "Open details" : "開啟細節",
     "Details" : "詳細資料",
+    "Currently present people" : "目前在場夥伴",
     "Loading board" : "正在載入佈告欄",
     "No lists available" : "沒有可用的列表",
     "Create a new list to add cards to this board" : "建立新列表以新增卡片到此佈告欄",
@@ -181,10 +186,12 @@ OC.L10N.register(
     "Transfer" : "轉移",
     "The board has been transferred to {user}" : "看板已轉移給 {user}",
     "Failed to transfer the board to {user}" : "轉移看板給 {user} 失敗",
-    "Add a new list" : "新增列表",
+    "Edit list title" : "編輯清單標題",
     "Archive all cards" : "封存所有卡片",
+    "Unarchive all cards" : "解除封存所有卡片",
     "Delete list" : "刪除列表",
     "Archive all cards in this list" : "封存此列表中的所有卡片",
+    "Unarchive all cards in this list" : "解除封存所有此列表中的卡片",
     "Add a new card" : "新增卡片",
     "Card name" : "卡片名稱",
     "List deleted" : "列表已刪除",
@@ -248,6 +255,7 @@ OC.L10N.register(
     "Assign to me" : "分配給我",
     "Unassign myself" : "取消分配給我",
     "Move card" : "移動卡片",
+    "Card details" : "卡片詳細資訊",
     "Unarchive card" : "解除封存卡片",
     "Archive card" : "封存卡片",
     "Delete card" : "刪除卡片",
@@ -260,6 +268,7 @@ OC.L10N.register(
     "Shared with you" : "與您分享",
     "Deck settings" : "Deck 設定",
     "Use bigger card view" : "使用較大的卡片檢視",
+    "Show card ID badge" : "顯示卡片 ID 徽章",
     "Show boards in calendar/tasks" : "在日曆／工作項目中顯示佈告欄",
     "Limit deck usage of groups" : "限制群組的 Deck 使用",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "限制 Deck 將會阻止不屬於這些群組的使用者建立自己的佈告欄。使用者仍然可以在與他們分享的佈告欄上工作。",
@@ -268,6 +277,7 @@ OC.L10N.register(
     "Clone board" : "再製佈告欄",
     "Unarchive board" : "解除封存佈告欄",
     "Archive board" : "封存佈告欄",
+    "Export board" : "匯出看板",
     "Turn on due date reminders" : "開啟到期日提醒",
     "Turn off due date reminders" : "關閉到期日提醒",
     "Due date reminders" : "到期日提醒",
@@ -285,11 +295,15 @@ OC.L10N.register(
     "No due" : "無到期日",
     "Search for {searchQuery} in all boards" : "在所有佈告欄中搜尋 {searchQuery}",
     "No results found" : "找不到結果",
+    "Deck board {name}\n* Last modified on {lastMod}" : "Deck 看板 {name}\n* 最後修改於 {lastMod}",
     "{stack} in {board}" : "{stack} 於 {board}",
+    "Click to expand description" : "點擊展開描述",
     "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* 建立於 {created}\n* 最後修改於 {lastMod}\n* {nbAttachments} 個附件\n* {nbComments} 則留言",
     "{nbCards} cards" : "{nbCards} 張卡片",
+    "Click to expand comment" : "點擊展開留言",
     "No upcoming cards" : "無接下來的卡片",
     "upcoming cards" : "接下來的卡片",
+    "New card" : "新卡片",
     "Due on {date}" : "於 {date} 到期",
     "Link to a board" : "連結到佈告欄",
     "Link to a card" : "連結到卡片",
@@ -302,12 +316,6 @@ OC.L10N.register(
     "Share with a Deck card" : "與 Deck 卡片分享",
     "Share {file} with a Deck card" : "與 Deck 卡片分享 {file}",
     "Share" : "分享",
-    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck 是一套看板式組織工具，提供與 Nextcloud 整合的個人規劃與團隊專案組織功能。\n\n\n- 📥 將您的工作項目新增到卡片中，並將它們按順序排列\n- 📄 以 Markdown 編寫額外的註釋\n- 🔖 分配標籤讓組織更方便\n- 👥 與您的團隊、朋友與家人分享\n- 📎 附上檔案並將其嵌入到您的 Markdown 描述中\n- 💬 使用留言與您的團隊討論\n- ⚡ 追蹤活動流程中的變動\n- 🚀 整理好您的專案",
-    "Are you sure you want to transfer the board {title} for {user} ?" : "您想要轉移 {user} 的看板 {title} 嗎？",
-    "Transfer the board for {user} successfully" : "轉移 {user} 的看板成功",
-    "Failed to transfer the board for {user}" : "轉移 {user} 的看板失敗",
-    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "您確定要刪除佈告欄 {title} 嗎？這將會刪除所有此佈告欄的資料。",
-    "This week" : "本週",
-    "Are you sure you want to transfer the board {title} for {user}?" : "您想要轉移 {user} 的看板 {title} 嗎？"
+    "Add a new list" : "新增列表"
 },
 "nplurals=1; plural=0;");
