@@ -325,7 +325,6 @@ class ActivityManager {
 		 */
 		$eventType = 'deck';
 		$subjectParams = [];
-		$message = null;
 		switch ($subject) {
 			// No need to enhance parameters since entity already contains the required data
 			case self::SUBJECT_BOARD_CREATE:
@@ -434,10 +433,6 @@ class ActivityManager {
 			->setSubject($subject, $subjectParams)
 			->setTimestamp(time());
 
-		if ($message !== null) {
-			$event->setMessage($message);
-		}
-
 		// FIXME: We currently require activities for comments even if they are disabled though settings
 		// Get rid of this once the frontend fetches comments/activity individually
 		if ($eventType === 'deck_comment') {
