@@ -34,6 +34,8 @@ use OCA\Deck\Db\CardMapper;
 use OCA\Deck\Db\ChangeHelper;
 use OCA\Deck\Db\IPermissionMapper;
 use OCA\Deck\Db\Label;
+use OCA\Deck\Db\Session;
+use OCA\Deck\Db\SessionMapper;
 use OCA\Deck\Db\Stack;
 use OCA\Deck\Db\StackMapper;
 use OCA\Deck\Event\AclCreatedEvent;
@@ -42,6 +44,7 @@ use OCA\Deck\Event\AclUpdatedEvent;
 use OCA\Deck\NoPermissionException;
 use OCA\Deck\Notification\NotificationHelper;
 use OCP\AppFramework\Db\DoesNotExistException;
+use OCP\AppFramework\Db\MultipleObjectsReturnedException;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IConfig;
 use OCP\IDBConnection;
@@ -53,8 +56,12 @@ use OCA\Deck\Db\BoardMapper;
 use OCA\Deck\Db\LabelMapper;
 use OCP\IUserManager;
 use OCA\Deck\BadRequestException;
+use OCA\Deck\Event\BoardUpdatedEvent;
+use OCA\Deck\Validators\BoardServiceValidator;
 use OCP\IURLGenerator;
 use OCP\Server;
+use Psr\Container\ContainerExceptionInterface;
+use Psr\Container\NotFoundExceptionInterface;
 
 class BoardService {
 	private BoardMapper $boardMapper;
@@ -73,13 +80,17 @@ class BoardService {
 	private IEventDispatcher $eventDispatcher;
 	private ChangeHelper $changeHelper;
 	private CardMapper $cardMapper;
-	private ?array $boardsCache = null;
+	private ?array $boardsCacheFull = null;
+	private ?array $boardsCachePartial = null;
 	private IURLGenerator $urlGenerator;
 	private IDBConnection $connection;
+	private BoardServiceValidator $boardServiceValidator;
+	private SessionMapper $sessionMapper;
 
 	public function __construct(
 		BoardMapper $boardMapper,
 		StackMapper $stackMapper,
+		CardMapper $cardMapper,
 		IConfig $config,
 		IL10N $l10n,
 		LabelMapper $labelMapper,
@@ -87,7 +98,6 @@ class BoardService {
 		PermissionService $permissionService,
 		NotificationHelper $notificationHelper,
 		AssignmentMapper $assignedUsersMapper,
-		CardMapper $cardMapper,
 		IUserManager $userManager,
 		IGroupManager $groupManager,
 		ActivityManager $activityManager,
@@ -95,10 +105,13 @@ class BoardService {
 		ChangeHelper $changeHelper,
 		IURLGenerator $urlGenerator,
 		IDBConnection $connection,
+		BoardServiceValidator $boardServiceValidator,
+		SessionMapper $sessionMapper,
 		?string $userId
 	) {
 		$this->boardMapper = $boardMapper;
 		$this->stackMapper = $stackMapper;
+		$this->cardMapper = $cardMapper;
 		$this->labelMapper = $labelMapper;
 		$this->config = $config;
 		$this->aclMapper = $aclMapper;
@@ -113,8 +126,9 @@ class BoardService {
 		$this->changeHelper = $changeHelper;
 		$this->userId = $userId;
 		$this->urlGenerator = $urlGenerator;
-		$this->cardMapper = $cardMapper;
 		$this->connection = $connection;
+		$this->boardServiceValidator = $boardServiceValidator;
+		$this->sessionMapper = $sessionMapper;
 	}
 
 	/**
@@ -135,94 +149,45 @@ class BoardService {
 	}
 
 	/**
-	 * @return array
+	 * @return Board[]
 	 */
-	public function findAll($since = -1, $details = null, $includeArchived = true) {
-		if ($this->boardsCache) {
-			return $this->boardsCache;
+	public function findAll(int $since = -1, bool $fullDetails = false, bool $includeArchived = true): array {
+		if ($this->boardsCacheFull && $fullDetails) {
+			return $this->boardsCacheFull;
 		}
+
+		if ($this->boardsCachePartial && !$fullDetails) {
+			return $this->boardsCachePartial;
+		}
+
 		$complete = $this->getUserBoards($since, $includeArchived);
-		$result = [];
-		/** @var Board $item */
-		foreach ($complete as &$item) {
-			$this->boardMapper->mapOwner($item);
-			if ($item->getAcl() !== null) {
-				foreach ($item->getAcl() as &$acl) {
-					$this->boardMapper->mapAcl($acl);
-				}
-			}
-			if ($details !== null) {
-				$this->enrichWithStacks($item);
-				$this->enrichWithLabels($item);
-				$this->enrichWithUsers($item);
-			}
-			$permissions = $this->permissionService->matchPermissions($item);
-			$item->setPermissions([
-				'PERMISSION_READ' => $permissions[Acl::PERMISSION_READ] ?? false,
-				'PERMISSION_EDIT' => $permissions[Acl::PERMISSION_EDIT] ?? false,
-				'PERMISSION_MANAGE' => $permissions[Acl::PERMISSION_MANAGE] ?? false,
-				'PERMISSION_SHARE' => $permissions[Acl::PERMISSION_SHARE] ?? false
-			]);
-			$this->enrichWithBoardSettings($item);
-			$result[$item->getId()] = $item;
-		}
-		$this->boardsCache = $result;
-		return array_values($result);
+		return $this->enrichBoards($complete, $fullDetails);
 	}
 
 	/**
-	 * @param $boardId
-	 * @return Board
 	 * @throws DoesNotExistException
 	 * @throws \OCA\Deck\NoPermissionException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
-	public function find($boardId) {
-		if ($this->boardsCache && isset($this->boardsCache[$boardId])) {
-			return $this->boardsCache[$boardId];
+	public function find(int $boardId, bool $fullDetails = true): Board {
+		$this->boardServiceValidator->check(compact('boardId'));
+
+		if (isset($this->boardsCacheFull[$boardId]) && $fullDetails) {
+			return $this->boardsCacheFull[$boardId];
 		}
-		if (is_numeric($boardId) === false) {
-			throw new BadRequestException('board id must be a number');
+
+		if (isset($this->boardsCachePartial[$boardId]) && !$fullDetails) {
+			return $this->boardsCachePartial[$boardId];
 		}
 
 		$this->permissionService->checkPermission($this->boardMapper, $boardId, Acl::PERMISSION_READ);
 		/** @var Board $board */
 		$board = $this->boardMapper->find($boardId, true, true);
-		$this->boardMapper->mapOwner($board);
-		if ($board->getAcl() !== null) {
-			foreach ($board->getAcl() as $acl) {
-				if ($acl !== null) {
-					$this->boardMapper->mapAcl($acl);
-				}
-			}
-		}
-		$permissions = $this->permissionService->matchPermissions($board);
-		$board->setPermissions([
-			'PERMISSION_READ' => $permissions[Acl::PERMISSION_READ] ?? false,
-			'PERMISSION_EDIT' => $permissions[Acl::PERMISSION_EDIT] ?? false,
-			'PERMISSION_MANAGE' => $permissions[Acl::PERMISSION_MANAGE] ?? false,
-			'PERMISSION_SHARE' => $permissions[Acl::PERMISSION_SHARE] ?? false
-		]);
-		$this->enrichWithUsers($board);
-		$this->enrichWithBoardSettings($board);
-		$this->boardsCache[$board->getId()] = $board;
+		[$board] = $this->enrichBoards([$board], $fullDetails);
 		return $board;
 	}
 
-	/**
-	 * @return array
-	 */
-	private function getBoardPrerequisites() {
-		$groups = $this->groupManager->getUserGroupIds(
-			$this->userManager->get($this->userId)
-		);
-		return [
-			'user' => $this->userId,
-			'groups' => $groups
-		];
-	}
-
 	/**
 	 * @param $mapper
 	 * @param $id
@@ -233,9 +198,7 @@ class BoardService {
 	 * @throws BadRequestException
 	 */
 	public function isArchived($mapper, $id) {
-		if (is_numeric($id) === false) {
-			throw new BadRequestException('id must be a number');
-		}
+		$this->boardServiceValidator->check(compact('id'));
 
 		try {
 			$boardId = $id;
@@ -262,13 +225,7 @@ class BoardService {
 	 * @throws BadRequestException
 	 */
 	public function isDeleted($mapper, $id) {
-		if ($mapper === false || $mapper === null) {
-			throw new BadRequestException('mapper must be provided');
-		}
-
-		if (is_numeric($id) === false) {
-			throw new BadRequestException('id must be a number');
-		}
+		$this->boardServiceValidator->check(compact('mapper', 'id'));
 
 		try {
 			$boardId = $id;
@@ -294,17 +251,7 @@ class BoardService {
 	 * @throws BadRequestException
 	 */
 	public function create($title, $userId, $color) {
-		if ($title === false || $title === null) {
-			throw new BadRequestException('title must be provided');
-		}
-
-		if ($userId === false || $userId === null) {
-			throw new BadRequestException('userId must be provided');
-		}
-
-		if ($color === false || $color === null) {
-			throw new BadRequestException('color must be provided');
-		}
+		$this->boardServiceValidator->check(compact('title', 'userId', 'color'));
 
 		if (!$this->permissionService->canCreate()) {
 			throw new NoPermissionException('Creating boards has been disabled for your account.');
@@ -355,9 +302,7 @@ class BoardService {
 	 * @throws BadRequestException
 	 */
 	public function delete($id) {
-		if (is_numeric($id) === false) {
-			throw new BadRequestException('board id must be a number');
-		}
+		$this->boardServiceValidator->check(compact('id'));
 
 		$this->permissionService->checkPermission($this->boardMapper, $id, Acl::PERMISSION_MANAGE);
 		$board = $this->find($id);
@@ -380,9 +325,7 @@ class BoardService {
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 */
 	public function deleteUndo($id) {
-		if (is_numeric($id) === false) {
-			throw new BadRequestException('board id must be a number');
-		}
+		$this->boardServiceValidator->check(compact('id'));
 
 		$this->permissionService->checkPermission($this->boardMapper, $id, Acl::PERMISSION_MANAGE);
 		$board = $this->find($id);
@@ -403,9 +346,7 @@ class BoardService {
 	 * @throws BadRequestException
 	 */
 	public function deleteForce($id) {
-		if (is_numeric($id) === false) {
-			throw new BadRequestException('id must be a number');
-		}
+		$this->boardServiceValidator->check(compact('id'));
 
 		$this->permissionService->checkPermission($this->boardMapper, $id, Acl::PERMISSION_MANAGE);
 		$board = $this->find($id);
@@ -426,21 +367,7 @@ class BoardService {
 	 * @throws BadRequestException
 	 */
 	public function update($id, $title, $color, $archived) {
-		if (is_numeric($id) === false) {
-			throw new BadRequestException('board id must be a number');
-		}
-
-		if ($title === false || $title === null) {
-			throw new BadRequestException('title must be provided');
-		}
-
-		if ($color === false || $color === null) {
-			throw new BadRequestException('color must be provided');
-		}
-
-		if (is_bool($archived) === false) {
-			throw new BadRequestException('archived must be a boolean');
-		}
+		$this->boardServiceValidator->check(compact('id', 'title', 'color', 'archived'));
 
 		$this->permissionService->checkPermission($this->boardMapper, $id, Acl::PERMISSION_MANAGE);
 		$board = $this->find($id);
@@ -453,6 +380,7 @@ class BoardService {
 		$this->boardMapper->mapOwner($board);
 		$this->activityManager->triggerUpdateEvents(ActivityManager::DECK_OBJECT_BOARD, $changes, ActivityManager::SUBJECT_BOARD_UPDATE);
 		$this->changeHelper->boardChanged($board->getId());
+		$this->eventDispatcher->dispatchTyped(new BoardUpdatedEvent($board->getId()));
 
 		return $board;
 	}
@@ -478,6 +406,18 @@ class BoardService {
 		$board->setSettings($settings);
 	}
 
+	public function enrichWithActiveSessions(Board $board) {
+		$sessions = $this->sessionMapper->findAllActive($board->getId());
+
+		$board->setActiveSessions(array_values(
+			array_unique(
+				array_map(function (Session $session) {
+					return $session->getUserId();
+				}, $sessions)
+			)
+		));
+	}
+
 	/**
 	 * @param $boardId
 	 * @param $type
@@ -490,29 +430,7 @@ class BoardService {
 	 * @throws \OCA\Deck\NoPermissionException
 	 */
 	public function addAcl($boardId, $type, $participant, $edit, $share, $manage) {
-		if (is_numeric($boardId) === false) {
-			throw new BadRequestException('board id must be a number');
-		}
-
-		if ($type === false || $type === null) {
-			throw new BadRequestException('type must be provided');
-		}
-
-		if ($participant === false || $participant === null) {
-			throw new BadRequestException('participant must be provided');
-		}
-
-		if ($edit === null) {
-			throw new BadRequestException('edit must be provided');
-		}
-
-		if ($share === null) {
-			throw new BadRequestException('share must be provided');
-		}
-
-		if ($manage === null) {
-			throw new BadRequestException('manage must be provided');
-		}
+		$this->boardServiceValidator->check(compact('boardId', 'type', 'participant', 'edit', 'share', 'manage'));
 
 		$this->permissionService->checkPermission($this->boardMapper, $boardId, Acl::PERMISSION_SHARE);
 		[$edit, $share, $manage] = $this->applyPermissions($boardId, $edit, $share, $manage);
@@ -558,21 +476,7 @@ class BoardService {
 	 * @throws BadRequestException
 	 */
 	public function updateAcl($id, $edit, $share, $manage) {
-		if (is_numeric($id) === false) {
-			throw new BadRequestException('id must be a number');
-		}
-
-		if ($edit === null) {
-			throw new BadRequestException('edit must be provided');
-		}
-
-		if ($share === null) {
-			throw new BadRequestException('share must be provided');
-		}
-
-		if ($manage === null) {
-			throw new BadRequestException('manage must be provided');
-		}
+		$this->boardServiceValidator->check(compact('id', 'edit', 'share', 'manage'));
 
 		$this->permissionService->checkPermission($this->aclMapper, $id, Acl::PERMISSION_SHARE);
 
@@ -592,12 +496,14 @@ class BoardService {
 	}
 
 	/**
+	 * @throws DbException
 	 * @throws DoesNotExistException
-	 * @throws \OCA\Deck\NoPermissionException
-	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
-	 * @throws BadRequestException
+	 * @throws NoPermissionException
+	 * @throws MultipleObjectsReturnedException
+	 * @throws ContainerExceptionInterface
+	 * @throws NotFoundExceptionInterface
 	 */
-	public function deleteAcl(int $id): bool {
+	public function deleteAcl(int $id): ?Acl {
 		$this->permissionService->checkPermission($this->aclMapper, $id, Acl::PERMISSION_SHARE);
 		/** @var Acl $acl */
 		$acl = $this->aclMapper->find($id);
@@ -622,8 +528,10 @@ class BoardService {
 			}
 		}
 
+		$deletedAcl = $this->aclMapper->delete($acl);
 		$this->eventDispatcher->dispatchTyped(new AclDeletedEvent($acl));
-		return (bool) $this->aclMapper->delete($acl);
+
+		return $deletedAcl;
 	}
 
 	/**
@@ -636,9 +544,7 @@ class BoardService {
 	 * @throws BadRequestException
 	 */
 	public function clone($id, $userId) {
-		if (is_numeric($id) === false) {
-			throw new BadRequestException('board id must be a number');
-		}
+		$this->boardServiceValidator->check(compact('id', 'userId'));
 
 		$this->permissionService->checkPermission($this->boardMapper, $id, Acl::PERMISSION_READ);
 
@@ -716,6 +622,66 @@ class BoardService {
 		}
 	}
 
+	/**
+	 * @param $id
+	 * @return Board
+	 * @throws DoesNotExistException
+	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
+	 * @throws BadRequestException
+	 */
+	public function export($id) : Board {
+		if (is_numeric($id) === false) {
+			throw new BadRequestException('board id must be a number');
+		}
+
+		$this->permissionService->checkPermission($this->boardMapper, $id, Acl::PERMISSION_READ);
+		$board = $this->boardMapper->find($id);
+		$this->enrichWithCards($board);
+		$this->enrichWithLabels($board);
+
+		return $board;
+	}
+
+	/** @param Board[] $boards */
+	private function enrichBoards(array $boards, bool $fullDetails = true): array {
+		$result = [];
+		foreach ($boards as $board) {
+			// FIXME The enrichment in here could make use of combined queries
+			$this->boardMapper->mapOwner($board);
+			if ($board->getAcl() !== null) {
+				foreach ($board->getAcl() as &$acl) {
+					$this->boardMapper->mapAcl($acl);
+				}
+			}
+
+			$permissions = $this->permissionService->matchPermissions($board);
+			$board->setPermissions([
+				'PERMISSION_READ' => $permissions[Acl::PERMISSION_READ] ?? false,
+				'PERMISSION_EDIT' => $permissions[Acl::PERMISSION_EDIT] ?? false,
+				'PERMISSION_MANAGE' => $permissions[Acl::PERMISSION_MANAGE] ?? false,
+				'PERMISSION_SHARE' => $permissions[Acl::PERMISSION_SHARE] ?? false
+			]);
+
+			if ($fullDetails) {
+				$this->enrichWithStacks($board);
+				$this->enrichWithLabels($board);
+				$this->enrichWithUsers($board);
+				$this->enrichWithBoardSettings($board);
+				$this->enrichWithActiveSessions($board);
+			}
+
+			// Cache for further usage
+			if ($fullDetails) {
+				$this->boardsCacheFull[$board->getId()] = $board;
+			} else {
+				$this->boardsCachePartial[$board->getId()] = $board;
+			}
+		}
+
+		return $boards;
+	}
+
 	private function enrichWithStacks($board, $since = -1) {
 		$stacks = $this->stackMapper->findAll($board->getId(), null, null, $since);
 
@@ -738,7 +704,7 @@ class BoardService {
 
 	private function enrichWithUsers($board, $since = -1) {
 		$boardUsers = $this->permissionService->findUsers($board->getId());
-		if (\count($boardUsers) === 0) {
+		if ($boardUsers === null || \count($boardUsers) === 0) {
 			return;
 		}
 		$board->setUsers(array_values($boardUsers));
@@ -748,10 +714,6 @@ class BoardService {
 		return $this->urlGenerator->linkToRouteAbsolute('deck.page.index') . '#' . $endpoint;
 	}
 
-	private function clearBoardsCache() {
-		$this->boardsCache = null;
-	}
-
 	/**
 	 * Clean a given board data from the Cache
 	 */
@@ -760,6 +722,26 @@ class BoardService {
 		$boardOwnerId = $board->getOwner();
 
 		$this->boardMapper->flushCache($boardId, $boardOwnerId);
-		unset($this->boardsCache[$boardId]);
+		unset($this->boardsCacheFull[$boardId]);
+		unset($this->boardsCachePartial[$boardId]);
+	}
+
+	private function enrichWithCards($board) {
+		$stacks = $this->stackMapper->findAll($board->getId());
+		foreach ($stacks as $stack) {
+			$cards = $this->cardMapper->findAllByStack($stack->getId());
+			$fullCards = [];
+			foreach ($cards as $card) {
+				$fullCard = $this->cardMapper->find($card->getId());
+				array_push($fullCards, $fullCard);
+			}
+			$stack->setCards($fullCards);
+		}
+
+		if (\count($stacks) === 0) {
+			return;
+		}
+
+		$board->setStacks($stacks);
 	}
 }
