@@ -28,21 +28,25 @@ namespace OCA\Deck\Service;
 
 use OCA\Deck\Activity\ActivityManager;
 use OCA\Deck\Activity\ChangeSet;
+use OCA\Deck\Db\Assignment;
 use OCA\Deck\Db\AssignmentMapper;
 use OCA\Deck\Db\Card;
 use OCA\Deck\Db\CardMapper;
 use OCA\Deck\Db\Acl;
 use OCA\Deck\Db\ChangeHelper;
+use OCA\Deck\Db\Label;
 use OCA\Deck\Db\StackMapper;
 use OCA\Deck\Event\CardCreatedEvent;
 use OCA\Deck\Event\CardDeletedEvent;
 use OCA\Deck\Event\CardUpdatedEvent;
+use OCA\Deck\Model\CardDetails;
 use OCA\Deck\NoPermissionException;
 use OCA\Deck\Notification\NotificationHelper;
 use OCA\Deck\Db\BoardMapper;
 use OCA\Deck\Db\LabelMapper;
 use OCA\Deck\StatusException;
 use OCA\Deck\BadRequestException;
+use OCA\Deck\Validators\CardServiceValidator;
 use OCP\Comments\ICommentsManager;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IRequest;
@@ -69,6 +73,7 @@ class CardService {
 	private IURLGenerator $urlGenerator;
 	private LoggerInterface $logger;
 	private IRequest $request;
+	private CardServiceValidator $cardServiceValidator;
 
 	public function __construct(
 		CardMapper $cardMapper,
@@ -88,6 +93,7 @@ class CardService {
 		IURLGenerator $urlGenerator,
 		LoggerInterface $logger,
 		IRequest $request,
+		CardServiceValidator $cardServiceValidator,
 		?string $userId
 	) {
 		$this->cardMapper = $cardMapper;
@@ -108,33 +114,60 @@ class CardService {
 		$this->urlGenerator = $urlGenerator;
 		$this->logger = $logger;
 		$this->request = $request;
+		$this->cardServiceValidator = $cardServiceValidator;
 	}
 
-	public function enrich($card) {
-		$cardId = $card->getId();
-		$this->cardMapper->mapOwner($card);
-		$card->setAssignedUsers($this->assignedUsersMapper->findAll($cardId));
-		$card->setLabels($this->labelMapper->findAssignedLabelsForCard($cardId));
-		$card->setAttachmentCount($this->attachmentService->count($cardId));
+	public function enrichCards($cards) {
 		$user = $this->userManager->get($this->currentUser);
-		$lastRead = $this->commentsManager->getReadMark('deckCard', (string)$card->getId(), $user);
-		$countUnreadComments = $this->commentsManager->getNumberOfCommentsForObject('deckCard', (string)$card->getId(), $lastRead);
-		$countComments = $this->commentsManager->getNumberOfCommentsForObject('deckCard', (string)$card->getId());
-		$card->setCommentsUnread($countUnreadComments);
-		$card->setCommentsCount($countComments);
 
-		$stack = $this->stackMapper->find($card->getStackId());
-		$board = $this->boardService->find($stack->getBoardId());
-		$card->setRelatedStack($stack);
-		$card->setRelatedBoard($board);
+		$cardIds = array_map(function (Card $card) use ($user) {
+			// Everything done in here might be heavy as it is executed for every card
+			$cardId = $card->getId();
+			$this->cardMapper->mapOwner($card);
+
+			$card->setAttachmentCount($this->attachmentService->count($cardId));
+
+			// TODO We should find a better way just to get the comment count so we can save 1-3 queries per card here
+			$countComments = $this->commentsManager->getNumberOfCommentsForObject('deckCard', (string)$card->getId());
+			$lastRead = $countComments > 0 ? $this->commentsManager->getReadMark('deckCard', (string)$card->getId(), $user) : null;
+			$countUnreadComments = $lastRead ? $this->commentsManager->getNumberOfCommentsForObject('deckCard', (string)$card->getId(), $lastRead) : 0;
+			$card->setCommentsUnread($countUnreadComments);
+			$card->setCommentsCount($countComments);
+
+			$stack = $this->stackMapper->find($card->getStackId());
+			$board = $this->boardService->find($stack->getBoardId(), false);
+			$card->setRelatedStack($stack);
+			$card->setRelatedBoard($board);
+
+			return $card->getId();
+		}, $cards);
+
+		$assignedLabels = $this->labelMapper->findAssignedLabelsForCards($cardIds);
+		$assignedUsers = $this->assignedUsersMapper->findIn($cardIds);
+
+		foreach ($cards as $card) {
+			$cardLabels = array_values(array_filter($assignedLabels, function (Label $label) use ($card) {
+				return $label->getCardId() === $card->getId();
+			}));
+			$cardAssignedUsers = array_values(array_filter($assignedUsers, function (Assignment $assignment) use ($card) {
+				return $assignment->getCardId() === $card->getId();
+			}));
+			$card->setLabels($cardLabels);
+			$card->setAssignedUsers($cardAssignedUsers);
+		}
+
+		return array_map(
+			function (Card $card): CardDetails {
+				return new CardDetails($card);
+			},
+			$cards
+		);
 	}
-
 	public function fetchDeleted($boardId) {
+		$this->cardServiceValidator->check(compact('boardId'));
 		$this->permissionService->checkPermission($this->boardMapper, $boardId, Acl::PERMISSION_READ);
 		$cards = $this->cardMapper->findDeleted($boardId);
-		foreach ($cards as $card) {
-			$this->enrich($card);
-		}
+		$this->enrichCards($cards);
 		return $cards;
 	}
 
@@ -148,16 +181,17 @@ class CardService {
 	public function find(int $cardId) {
 		$this->permissionService->checkPermission($this->cardMapper, $cardId, Acl::PERMISSION_READ);
 		$card = $this->cardMapper->find($cardId);
-		$assignedUsers = $this->assignedUsersMapper->findAll($card->getId());
+		[$card] = $this->enrichCards([$card]);
+
+		// Attachments are only enriched on individual card fetching
 		$attachments = $this->attachmentService->findAll($cardId, true);
 		if ($this->request->getParam('apiVersion') === '1.0') {
 			$attachments = array_filter($attachments, function ($attachment) {
 				return $attachment->getType() === 'deck_file';
 			});
 		}
-		$card->setAssignedUsers($assignedUsers);
 		$card->setAttachments($attachments);
-		$this->enrich($card);
+
 		return $card;
 	}
 
@@ -169,9 +203,7 @@ class CardService {
 			return [];
 		}
 		$cards = $this->cardMapper->findCalendarEntries($boardId);
-		foreach ($cards as $card) {
-			$this->enrich($card);
-		}
+		$this->enrichCards($cards);
 		return $cards;
 	}
 
@@ -190,29 +222,7 @@ class CardService {
 	 * @throws BadrequestException
 	 */
 	public function create($title, $stackId, $type, $order, $owner, $description = '', $duedate = null) {
-		if ($title === 'false' || $title === null) {
-			throw new BadRequestException('title must be provided');
-		}
-
-		if (mb_strlen($title) > Card::TITLE_MAX_LENGTH) {
-			throw new BadRequestException('The title cannot exceed 255 characters');
-		}
-
-		if (is_numeric($stackId) === false) {
-			throw new BadRequestException('stack id must be a number');
-		}
-
-		if ($type === 'false' || $type === null) {
-			throw new BadRequestException('type must be provided');
-		}
-
-		if (is_numeric($order) === false) {
-			throw new BadRequestException('order must be a number');
-		}
-
-		if ($owner === false || $owner === null) {
-			throw new BadRequestException('owner must be provided');
-		}
+		$this->cardServiceValidator->check(compact('title', 'stackId', 'type', 'order', 'owner'));
 
 		$this->permissionService->checkPermission($this->stackMapper, $stackId, Acl::PERMISSION_EDIT);
 		if ($this->boardService->isArchived($this->stackMapper, $stackId)) {
@@ -282,29 +292,7 @@ class CardService {
 	 * @throws BadRequestException
 	 */
 	public function update($id, $title, $stackId, $type, $owner, $description = '', $order = 0, $duedate = null, $deletedAt = null, $archived = null) {
-		if (is_numeric($id) === false) {
-			throw new BadRequestException('card id must be a number');
-		}
-
-		if ($title === false || $title === null) {
-			throw new BadRequestException('title must be provided');
-		}
-
-		if (mb_strlen($title) > Card::TITLE_MAX_LENGTH) {
-			throw new BadRequestException('The title cannot exceed 255 characters');
-		}
-
-		if (is_numeric($stackId) === false) {
-			throw new BadRequestException('stack id must be a number $$$');
-		}
-
-		if ($type === false || $type === null) {
-			throw new BadRequestException('type must be provided');
-		}
-
-		if ($owner === false || $owner === null) {
-			throw new BadRequestException('owner must be provided');
-		}
+		$this->cardServiceValidator->check(compact('id', 'title', 'stackId', 'type', 'owner', 'order'));
 
 		$this->permissionService->checkPermission($this->cardMapper, $id, Acl::PERMISSION_EDIT);
 		$this->permissionService->checkPermission($this->stackMapper, $stackId, Acl::PERMISSION_EDIT);
@@ -371,7 +359,7 @@ class CardService {
 		}
 		$this->changeHelper->cardChanged($card->getId(), true);
 
-		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card));
+		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card, $changes->getBefore()));
 
 		return $card;
 	}
@@ -387,17 +375,7 @@ class CardService {
 	 * @throws BadRequestException
 	 */
 	public function rename($id, $title) {
-		if (is_numeric($id) === false) {
-			throw new BadRequestException('id must be a number');
-		}
-
-		if ($title === false || $title === null) {
-			throw new BadRequestException('title must be provided');
-		}
-
-		if (mb_strlen($title) > Card::TITLE_MAX_LENGTH) {
-			throw new BadRequestException('The title cannot exceed 255 characters');
-		}
+		$this->cardServiceValidator->check(compact('id', 'title'));
 
 		$this->permissionService->checkPermission($this->cardMapper, $id, Acl::PERMISSION_EDIT);
 		if ($this->boardService->isArchived($this->cardMapper, $id)) {
@@ -428,17 +406,8 @@ class CardService {
 	 * @throws BadRequestException
 	 */
 	public function reorder($id, $stackId, $order) {
-		if (is_numeric($id) === false) {
-			throw new BadRequestException('card id must be a number');
-		}
+		$this->cardServiceValidator->check(compact('id', 'stackId', 'order'));
 
-		if (is_numeric($stackId) === false) {
-			throw new BadRequestException('stack id must be a number');
-		}
-
-		if (is_numeric($order) === false) {
-			throw new BadRequestException('order must be a number');
-		}
 
 		$this->permissionService->checkPermission($this->cardMapper, $id, Acl::PERMISSION_EDIT);
 		$this->permissionService->checkPermission($this->stackMapper, $stackId, Acl::PERMISSION_EDIT);
@@ -480,6 +449,8 @@ class CardService {
 			$result[$card->getOrder()] = $card;
 		}
 		$this->changeHelper->cardChanged($id, false);
+		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card));
+
 		return array_values($result);
 	}
 
@@ -493,9 +464,8 @@ class CardService {
 	 * @throws BadRequestException
 	 */
 	public function archive($id) {
-		if (is_numeric($id) === false) {
-			throw new BadRequestException('id must be a number');
-		}
+		$this->cardServiceValidator->check(compact('id'));
+
 
 		$this->permissionService->checkPermission($this->cardMapper, $id, Acl::PERMISSION_EDIT);
 		if ($this->boardService->isArchived($this->cardMapper, $id)) {
@@ -523,9 +493,8 @@ class CardService {
 	 * @throws BadRequestException
 	 */
 	public function unarchive($id) {
-		if (is_numeric($id) === false) {
-			throw new BadRequestException('id must be a number');
-		}
+		$this->cardServiceValidator->check(compact('id'));
+
 
 		$this->permissionService->checkPermission($this->cardMapper, $id, Acl::PERMISSION_EDIT);
 		if ($this->boardService->isArchived($this->cardMapper, $id)) {
@@ -552,13 +521,8 @@ class CardService {
 	 * @throws BadRequestException
 	 */
 	public function assignLabel($cardId, $labelId) {
-		if (is_numeric($cardId) === false) {
-			throw new BadRequestException('card id must be a number');
-		}
+		$this->cardServiceValidator->check(compact('cardId', 'labelId'));
 
-		if (is_numeric($labelId) === false) {
-			throw new BadRequestException('label id must be a number');
-		}
 
 		$this->permissionService->checkPermission($this->cardMapper, $cardId, Acl::PERMISSION_EDIT);
 		if ($this->boardService->isArchived($this->cardMapper, $cardId)) {
@@ -586,13 +550,8 @@ class CardService {
 	 * @throws BadRequestException
 	 */
 	public function removeLabel($cardId, $labelId) {
-		if (is_numeric($cardId) === false) {
-			throw new BadRequestException('card id must be a number');
-		}
+		$this->cardServiceValidator->check(compact('cardId', 'labelId'));
 
-		if (is_numeric($labelId) === false) {
-			throw new BadRequestException('label id must be a number');
-		}
 
 		$this->permissionService->checkPermission($this->cardMapper, $cardId, Acl::PERMISSION_EDIT);
 		if ($this->boardService->isArchived($this->cardMapper, $cardId)) {
